@@ -1,5 +1,5 @@
 # encoding=UTF-8
-# Copyright © 2009 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +15,12 @@ import os
 
 from xdg import BaseDirectory as xdg
 
+if os.name == 'nt':
+    # On Windows, use the “Application Data” folder if XDG_CONFIG_HOME is
+    # not set.
+    if ('XDG_CONFIG_HOME' not in os.environ) and ('APPDATA' in os.environ):
+        xdg.xdg_config_home = os.environ['APPDATA']
+
 class Config(object):
 
     def __init__(self, resource, legacy_path=None):
@@ -54,6 +60,7 @@ class Config(object):
                     key, value = line.split('=', 1)
                 except ValueError:
                     pass
+                value = value.decode('UTF-8')
                 self._data[key] = value
         finally:
             file.close()
@@ -67,12 +74,21 @@ class Config(object):
         file = open(tmp_path, 'w')
         try:
             for key, value in self._data.iteritems():
+                if isinstance(value, unicode):
+                    value = value.encode('UTF-8')
                 file.write('%s=%s\n' % (key, value))
             file.flush()
             os.fsync(file.fileno())
         finally:
             file.close()
-        os.rename(tmp_path, path)
+        if os.name != 'posix' and os.path.exists(path):
+            # Atomic renames might be not supported.
+            backup_path = path + '.bak'
+            os.rename(path, backup_path)
+            os.rename(tmp_path, path)
+            os.remove(backup_path)
+        else:
+            os.rename(tmp_path, path)
         if self._legacy_path is not None:
             try:
                 os.remove(self._legacy_path)
