@@ -1,5 +1,5 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,26 @@ WX_VERSIONS = ('2.8-unicode', '2.6-unicode')
 DDJVU_API_MIN_VERSION = 26
 PYTHON_DJVULIBRE_MIN_VERSION = (0, 1, 4)
 
+djvulibre_path = None
+
+def _check_signals():
+    # Protect from scanadf[0] and possibly other brain-dead software that set
+    # SIGCHLD to SIG_IGN.
+    # [0] http://bugs.debian.org/596232
+    import os
+    import signal
+    if os.name == 'posix':
+        signal.signal(signal.SIGCHLD, signal.SIG_DFL)
+
 def _check_djvu():
+    # On Windows, special measures may be needed to find the DjVuLibre DLL.
+    global djvulibre_path
+    try:
+        from djvu.dllpath import set_dll_search_path
+    except ImportError:
+        pass
+    else:
+        djvulibre_path = set_dll_search_path()
     try:
         from djvu.decode import __version__ as djvu_decode_version
     except ImportError, ex:
@@ -45,6 +64,8 @@ def _check_xdg():
     except ImportError, ex:
         raise ImportError('%s; perhaps pyxdg is not installed' % (ex,))
 
+_check_signals()
+del _check_signals
 try:
     _check_djvu()
 finally:
