@@ -1,5 +1,5 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
 # This package is free software; you can redistribute it and/or modify
@@ -11,6 +11,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
+from __future__ import with_statement
+
 APPLICATION_NAME = 'djvusmooth'
 LICENSE = 'GPL-2'
 
@@ -754,26 +756,22 @@ class MainWindow(wx.Frame):
 
     def on_external_edit_outline(self, event):
         model = self.outline_model
-        def job():
+        def job(disabler):
             new_repr = None
             try:
-                tmp_file = tempfile.NamedTemporaryFile(suffix='.txt')
-                try:
+                with external_editor.temporary_file(suffix='.txt') as tmp_file:
                     model.export_as_plaintext(tmp_file)
                     tmp_file.flush()
                     self.external_editor(tmp_file.name)
                     tmp_file.seek(0)
                     new_repr = map(str.expandtabs, itertools.imap(str.rstrip, tmp_file))
-                finally:
-                    tmp_file.close()
             except Exception, exception:
                 pass
             else:
                 exception = None
             wx.CallAfter(lambda: self.after_external_edit_outline(new_repr, disabler, exception))
-            disabler = None
         disabler = wx.WindowDisabler()
-        thread = threading.Thread(target = job)
+        thread = threading.Thread(target=job, args=(disabler,))
         thread.start()
 
     def on_external_edit_failed(self, exception):
@@ -791,11 +789,10 @@ class MainWindow(wx.Frame):
         if not sexpr:
             self.error_box(_('No text layer to edit.'))
             return
-        def job():
+        def job(disabler):
             new_sexpr = None
             try:
-                tmp_file = tempfile.NamedTemporaryFile(suffix='.txt')
-                try:
+                with external_editor.temporary_file(suffix='.txt') as tmp_file:
                     text_mangle.export(sexpr, tmp_file)
                     tmp_file.flush()
                     self.external_editor(tmp_file.name)
@@ -804,16 +801,13 @@ class MainWindow(wx.Frame):
                         new_sexpr = text_mangle.import_(sexpr, tmp_file)
                     except text_mangle.NothingChanged:
                         pass
-                finally:
-                    tmp_file.close()
             except Exception, exception:
                 pass
             else:
                 exception = None
             wx.CallAfter(lambda: self.after_external_edit_text(new_sexpr, disabler, exception))
-            disabler = None
         disabler = wx.WindowDisabler()
-        thread = threading.Thread(target = job)
+        thread = threading.Thread(target=job, args=(disabler,))
         thread.start()
 
     def after_external_edit_text(self, sexpr, disabler, exception):
@@ -991,7 +985,11 @@ class Application(wx.App):
     def OnInit(self):
         wx.lib.ogl.OGLInitialize()
         self.SetAppName(APPLICATION_NAME)
-        self._config = config.Config('djvusmooth', os.path.expanduser('~/.DjVuSmooth'))
+        if os.name == 'posix':
+            legacy_path = os.path.expanduser('~/.DjVuSmooth')
+        else:
+            legacy_path = None
+        self._config = config.Config('djvusmooth', legacy_path)
         sys.excepthook = self.except_hook
         return True
 
